# NRSurrogate catalog
![PyPI](https://img.shields.io/pypi/v/nrsur_catalog)

This repository contains the python package source code for the NRSurrogate Catalog API.
Install the package with
```
pip install nrsur_catalog
```

This allows users to download catalog data in the CLI, or load results and make plots from within python.
